# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2017-02-12 17:43
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('plugs_media', '0007_media_user'),
    ]

    operations = [
        migrations.CreateModel(
            name='MediaContentType',
            fields=[
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('id', models.CharField(max_length=201, primary_key=True, serialize=False)),
                ('app_label', models.CharField(max_length=100)),
                ('model', models.CharField(max_length=100)),
            ],
            options={
                'verbose_name_plural': 'media_content_types',
                'verbose_name': 'media_content_type',
            },
        ),
    ]
