# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2017-01-09 22:46
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('plugs_media', '0003_auto_20170109_2240'),
    ]

    operations = [
        migrations.RenameField(
            model_name='media',
            old_name='object_id',
            new_name='model_object',
        ),
        migrations.RemoveField(
            model_name='media',
            name='content_type',
        ),
        migrations.AddField(
            model_name='media',
            name='model',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
