# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-09-13 21:44
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('plugs_media', '0010_auto_20170814_1627'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='media',
            options={'ordering': ('pk',), 'verbose_name': 'media', 'verbose_name_plural': 'media'},
        ),
    ]
